#include <stdlib.h>
#include "sauna.h"

/* Internally used globals */
static SDL_Surface *thermometer[2];
static SDL_Surface *stamina[2];
static float temp_delta,temp_delta2;

/* Exported globals */
float temperature;

void initGauges(void) {
	thermometer[0]=loadPng("thermo_empty.png");
	if(!thermometer[0]) {
		fprintf(stderr,"Couldn't load thermo_empty.png !\n");
		exit(-1);
	}
	thermometer[1]=loadPng("thermo_full.png");
	if(!thermometer[1]) {
		fprintf(stderr,"Couldn't load thermo_full.png !\n");
		exit(-1);
	}
	stamina[0]=loadPng("stamina_empty.png");
	if(!stamina[0]) {
		fprintf(stderr,"Couldn't load stamina_empty.png !\n");
		exit(-1);
	}
	stamina[1]=loadPng("stamina_full.png");
	if(!stamina[1]) {
		fprintf(stderr,"Couldn't load stamina_full.png !\n");
		exit(-1);
	}

	temperature=60.0;
	temp_delta=0;
}

void deinitGauges(void) {
	SDL_FreeSurface(thermometer[0]);
	SDL_FreeSurface(thermometer[1]);
	SDL_FreeSurface(stamina[0]);
	SDL_FreeSurface(stamina[1]);
}

void animateThermal(float t) {
	temperature-=0.16*t;
	if(temp_delta) {
		temperature+=temp_delta*t;
		temp_delta2+=temp_delta*t;
		if(temp_delta<0) {
			if(temp_delta>temp_delta2) temp_delta=0;
		} else {
			if(temp_delta<temp_delta2) temp_delta=0;
		}
	}
}

void changeTemperature(float d) {
	temp_delta=d;
	temp_delta2=0;
}

/* Ylin: 61  (140C) */
/* Alin: 280 (20C) */
void drawThermo(float temp) {
	SDL_Rect src,targ;
	if(temp>140.0) temp=140.0;
	if(temp<20.0) temp=20.0;
	temp=(temp-20.0)/120.0;
	/* Blit empty thermometer */
	src.x=0; src.y=0;
	src.w=thermometer[0]->w;
	src.h=61+(219*(1.0-temp));
	targ.x=screen->w-thermometer[0]->w;
	targ.y=0;
	SDL_BlitSurface(thermometer[0],&src,screen,&targ);
	/* Blit full thermometer */
	targ.y=src.h;
	src.y=src.h;
	src.h=thermometer[1]->h-src.h;
	SDL_BlitSurface(thermometer[1],&src,screen,&targ);
}

void eraseThermo(void) {
	SDL_Rect rect;
	rect.x=screen->w-thermometer[0]->w;
	rect.y=0;
	rect.w=thermometer[0]->w;
	rect.h=thermometer[0]->h;
	SDL_BlitSurface(background,&rect,screen,&rect);
}

/* Alin: 110 */
void drawStamina(float s) {
	SDL_Rect src,targ;
	if(s>1.0) s=1.0;
	else if(s<0.0) s=0.0;
	/* Blit empty stamina gauge */
	src.x=0;
	src.y=0;
	src.w=stamina[0]->w;
	src.h=stamina[0]->h*(1.0-s);
	targ.x=screen->w-stamina[0]->w;
	targ.y=screen->h-stamina[0]->h-10;
	SDL_BlitSurface(stamina[0],&src,screen,&targ);
	/* Blit full stamina gauge */
	src.y=src.h;
	src.h=stamina[1]->h-src.y;
	targ.y+=src.y;
	SDL_BlitSurface(stamina[1],&src,screen,&targ);
}

void eraseStamina(void) {
	SDL_Rect rect;
	rect.x=screen->w-stamina[0]->w;
	rect.y=screen->h-stamina[0]->h-10;
	rect.w=stamina[0]->w;
	rect.h=stamina[0]->h;
	SDL_BlitSurface(background,&rect,screen,&rect);
}

